psicons.core

Package psicons :: Package core |
[hide private]
[frames] | no frames]

# Package core

source code

A hack to subvert the scons build system for scientific analysis.

Psicons allows scripts and external programs for analysis to be incorporated into a build procedure. Every stage of analysis is a command-line call to a script or executable that takes inputs and produces outputs. When scons is called, dependencies between outputs and inputs are tested and only those stages are run that are necessary to update outputs. In addition, the exact sequence of analyses recorded by the build file.

Version: 0.1

Author: Paul-Michael Agapow (pma@agapow.net)

Submodules | [hide private]
psicons.core.commands: New scons commands. psicons.core.impl: Internal implementation utilities and details. psicons.core.utils: Miscellaneous utilities for use in writing and using commands.

Variables | [hide private]
| __package__ = ``'``psicons.core``'``